Function resolve_item_key

fn resolve_item_key(ctx: &ServerContext, key: &str) -> Result<String, String>
Resolve an identifier that may be either a Zotero item key (8-char) or a BBT citekey.

Zotero item keys are 8 alphanumeric characters (e.g., “TQPUXSC2”). Anything longer is treated as a citekey and resolved via BBT. We accept item keys without verifying in SQLite because freshly created items may not have synced to the local database yet.